gin

package module
v1.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 3, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

==== File: integrations/gin/gin.go ==== Package gin provides a renderer for the Gin framework.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Renderer

type Renderer struct {
	*templates.Templates
}

Renderer implements the gin.HTMLRenderer interface, allowing the templates engine to be used as the default HTML renderer in Gin.

func New

func New(tmpls *templates.Templates) *Renderer

New creates a new Renderer instance for Gin from a configured templates.Templates instance.

func (*Renderer) Instance

func (r *Renderer) Instance(name string, data interface{}) render.Render

Instance returns a gin.HTMLRender instance for a given template name and data. It is called by c.HTML() in a Gin handler.

Jump to